@@ -1,17 +1,23 @@
 import logging
+from typing import Type, Union
 
 from . import SchemaFactory
 from ..enumeration import ContentType
 from ..specification import Content
+from ..loose_types import LooseContentType
 
 logger = logging.getLogger(__name__)
 
+ContentTypeType = Union[Type[ContentType], Type[LooseContentType]]
+
 
 class ContentBuilder:
     schema_factory: SchemaFactory
+    strict_enum: bool
 
-    def __init__(self, schema_factory: SchemaFactory) -> None:
+    def __init__(self, schema_factory: SchemaFactory, strict_enum: bool = True) -> None:
         self.schema_factory = schema_factory
+        self.strict_enum = strict_enum
 
     def build_list(self, data: dict) -> list[Content]:
         return [
@@ -22,8 +28,8 @@ class ContentBuilder:
 
     def _create_content(self, content_type: str, content_value: dict) -> Content:
         logger.debug(f"Content building [type={content_type}]")
-
+        ContentTypeCls: ContentTypeType = ContentType if self.strict_enum else LooseContentType
         return Content(
-            type=ContentType(content_type),
+            type=ContentTypeCls(content_type),
             schema=self.schema_factory.create(content_value)
         )
