@@ -10,6 +10,7 @@ class DataType(Enum):
     ARRAY = 'array'
     OBJECT = 'object'
     ONE_OF = 'oneOf'
+    ANY_OF = 'anyOf'
 
 
 @unique
@@ -63,6 +64,31 @@ class ParameterLocation(Enum):
     PATH = 'path'
 
 
+@unique
+class PathParameterStyle(Enum):
+    SIMPLE = 'simple'
+    LABEL = 'label'
+    MATRIX = 'matrix'
+
+
+@unique
+class QueryParameterStyle(Enum):
+    FORM = 'form'
+    SPACE_DELIMITED = 'spaceDelimited'
+    PIPE_DELIMITED = 'pipeDelimited'
+    DEEP_OBJECT = 'deepObject'
+
+
+@unique
+class HeaderParameterStyle(Enum):
+    SIMPLE = 'simple'
+
+
+@unique
+class CookieParameterStyle(Enum):
+    FORM = 'form'
+
+
 @unique
 class ContentType(Enum):
     JSON = 'application/json'
